@@ -1,19 +1,28 @@
-#include "ace/Log_Msg.h"
+// producer_msg.cpp,v 4.10 2003/11/01 11:15:23 dhinton Exp
+
+#include "ace/OS_main.h"
 #include "ace/SPIPE_Addr.h"
 #include "ace/SPIPE_Connector.h"
-#include "shared.h"
+#include "ace/Log_Msg.h"
+#include "ace/OS_NS_stdio.h"
+
+ACE_RCSID(SPIPE_SAP, producer_msg, "producer_msg.cpp,v 4.10 2003/11/01 11:15:23 dhinton Exp")
 
 #if defined (ACE_HAS_STREAM_PIPES)
 
+#include "shared.h"
+
 const int DEFAULT_SIZE = 4 * 1024;
 const int DEFAULT_COUNT = 100;
 
-int 
-main (int argc, char *argv[])
+int
+ACE_TMAIN (int argc, ACE_TCHAR *argv[])
 {
-  int  size       = argc > 1 ? atoi (argv[1]) : DEFAULT_SIZE;
-  int  iterations = argc > 2 ? atoi (argv[2]) : DEFAULT_COUNT;
-  char *buf	  = new char[size];
+  int size = argc > 1 ? ACE_OS::atoi (argv[1]) : DEFAULT_SIZE;
+  int iterations = argc > 2 ? ACE_OS::atoi (argv[2]) : DEFAULT_COUNT;
+  char *buf;
+
+  ACE_NEW_RETURN (buf, char[size], -1);
 
   if (argc > 3)
     rendezvous = argv[3];
@@ -31,7 +40,10 @@ main (int argc, char *argv[])
   ACE_Str_Buf buffer (buf, size);
 
   for (i = 0; i < iterations; i++)
-    if (cli_stream.send ((ACE_Str_Buf *) 0, &buffer) == -1)
+    if (cli_stream.send ((ACE_Str_Buf *) 0,
+			 &buffer,
+			 1,
+			 MSG_BAND) == -1)
       ACE_ERROR_RETURN ((LM_ERROR, "%p\n", "send"), 1);
 
   if (cli_stream.close () == -1)
@@ -42,7 +54,7 @@ main (int argc, char *argv[])
 }
 #else
 #include <stdio.h>
-int main (void)
+int ACE_TMAIN (int, ACE_TCHAR *[])
 {
   ACE_OS::fprintf (stderr, "This feature is not supported\n");
   return 0;
