@@ -1,9 +1,15 @@
+// logging_app.cpp,v 4.7 2003/11/01 11:15:23 dhinton Exp
+
 // This program sends logging records directly to the server, rather
 // than going through the client logging daemon.
 
 #include "ace/SOCK_Connector.h"
-#include "ace/Log_Msg.h"
 #include "ace/Log_Record.h"
+#include "ace/Log_Msg.h"
+#include "ace/OS_NS_time.h"
+#include "ace/OS_NS_stdio.h"
+
+ACE_RCSID(client, logging_app, "logging_app.cpp,v 4.7 2003/11/01 11:15:23 dhinton Exp")
 
 static u_short LOGGER_PORT = ACE_DEFAULT_SERVER_PORT;
 static const char *const LOGGER_HOST = ACE_DEFAULT_SERVER_HOST;
@@ -20,17 +26,17 @@ main (int argc, char *argv[])
   ACE_SOCK_Connector connector;
   ACE_INET_Addr addr (logger_port, logger_host);
 
-  ACE_Log_Record log_record (LM_DEBUG, 
-			     ACE_OS::time ((time_t *) 0), 
-			     ACE_OS::getpid ());
-
   if (connector.connect (logger, addr) == -1)
     ACE_ERROR_RETURN ((LM_ERROR, "%p\n", "open"), -1);
   
   for (int i = 0; i < max_iterations; i++)
     {
+      ACE_Log_Record log_record (LM_DEBUG, 
+				 ACE_OS::time ((time_t *) 0), 
+				 ACE_OS::getpid ());
+
       char buf[BUFSIZ];
-      ::sprintf (buf, "message = %d\n", i + 1);
+      ACE_OS::sprintf (buf, "message = %d\n", i + 1);
       log_record.msg_data (buf);
       size_t len = log_record.length ();
       size_t encoded_len = htonl (len);
@@ -43,6 +49,7 @@ main (int argc, char *argv[])
       else
 	ACE_OS::sleep (1);
     }
+
   if (logger.close () == -1)
     ACE_ERROR_RETURN ((LM_ERROR, "%p\n", "close"), -1);
 
