@@ -1,5 +1,12 @@
-#include "ace/Log_Msg.h"
+// test_MM.cpp,v 4.6 2003/11/01 11:15:24 dhinton Exp
+
 #include "ace/Shared_Memory_MM.h"
+#include "ace/Log_Msg.h"
+#include "ace/OS_NS_errno.h"
+#include "ace/OS_NS_unistd.h"
+#include "ace/OS_NS_stdlib.h"
+
+ACE_RCSID(Shared_Memory, test_MM, "test_MM.cpp,v 4.6 2003/11/01 11:15:24 dhinton Exp")
 
 #define SHMSZ 27
 char shm_key[] = "/tmp/fooXXXXXX";
@@ -49,6 +56,7 @@ main (int, char *[])
     case -1:
       ACE_ERROR_RETURN ((LM_ERROR, "%p\n", "fork"), 1);
     case 0: 
+      // Make sure the server starts up first.
       ACE_OS::sleep (1); 
       client ();
       break;
